﻿using System;
using System.IO;

using Bluefin.Data;
using Bluefin.Web.Client;

namespace Bluefin_Dotnet_Guide
{
    public class ReportTester
    {
        static void Main(string[] args)
        {
            ReportTester tester = new ReportTester();
            tester.RunAllTests();
        }

        public void RunAllTests()
        {
            ReportAllTransactions();
            //ReportCardTransactions();
            //ReportCheckTransactions();
        }

        /// <summary>
        /// Run test transactions and then download report.
        /// </summary>
        public void ReportAllTransactions()
        {
            // Use TransactionsTester to run transactions
            TransactionsTester transTester = new TransactionsTester();
            transTester.CardSale();
            transTester.CheckSale();

            // Instantiate request for transactions report
            TransactionsReportRequest request = new TransactionsReportRequest();

            request.TransactionDate = DateTime.Today.ToString("yyyy-MM-dd");
            request.FileName        = @".\AllTransactions.csv"; // file name is required
            request.PersistMode     = ReportRequest.PersistModeOptions.FILE;
            request.ReportFormat    = ReportFormat.CSV;

            TransactionsReportResponse response = ReportTransactions(request);
 
            if (response.Success())
            {
                // Output file with todays transactions (should be at least two: one card and one check)
                Console.WriteLine("\nTransactions Report Follows ...");
                Console.Write(File.ReadAllText(response.FileName));
            }
        }

        public TransactionsReportResponse ReportTransactions(TransactionsReportRequest request)
        {
            Console.Write("\nRequesting Transactions Report ..."
                + LogHelper.ToLogString(request, "\n\t")
            );

            TransactionsReportResponse response = 
                BluefinGateway.Report.Transactions(request);

            Console.Write("\nResponse ..."
                + LogHelper.ToLogString(response, "\n\t"));

            return response;
        }
    }
}
