﻿using System;

using Bluefin.Data;
using Bluefin.Web.Client;

namespace Bluefin_Dotnet_Guide
{
    /// <summary>
    /// This class incapsulate code and data for numerous tests of 
    /// Bluefin SchedulingServiceGateway.
    /// </summary>
    public class ScheduleTester
    {
        /// <summary>
        /// Gets last test recurring id.
        /// </summary>
        public String RecurringID
        {
            get;
            protected set;
        }

        static void Main(string[] args)
        {
            ScheduleTester tester = new ScheduleTester();
            tester.RunAllTests();
        }

        public void RunAllTests()
        {
            Boolean isOk =
                ScheduleRecurringPayment()
                && EditRecurringPayment()
                ;

            Console.WriteLine("All tests succeded: {0}", isOk);
        }

        /// <summary>
        /// Schedules recurring payment for known card transaction.
        /// </summary>
        public Boolean ScheduleRecurringPayment()
        {
            Console.WriteLine("ScheduleRecurringPayment()");

            // Store (tokenize) card 1st. We recommend to run AuthorizeCard() 
            // with recurring payment amount.
            TransactionsTester transTester = new TransactionsTester();
            if (!transTester.StoreCard())
                return false;

            // Reset class variable
            this.RecurringID = null;

            // Create Recurring schedule
            SchedulingRequest request = new SchedulingRequest();

            request.RecurringPaymentAmount     = new BluefinAmount(175.00);                  // Pay $175.00
            request.RecurringPaymentsRemaining = new BluefinInteger(4);                      // Four times
            request.RecurringSchedule           = RecurringSchedule.MONTHLY_1;               // on 1st day of Month     
            request.StartDate = new BluefinDate(DateTime.Now.AddDays(1));   // starting tomorrow
            request.TokenID                    = transTester.TransactionID;                  // using id of stored card

            Console.WriteLine("Scheduling Request ..."
                + LogHelper.ToLogString(request, "\n\t"));

            SchedulingResponse response = BluefinGateway.Schedule.Setup(request);

            Console.WriteLine("Scheduling Response ..."
                + LogHelper.ToLogString(response, "\n\t"));

            // Store RecurringID for other tests that may follow
            this.RecurringID = response.RecurringID;

            return response.Success();
        }

        /// <summary>
        /// Edit recurring payment that was created by CreateRecurringPayment() test
        /// </summary>
        public Boolean EditRecurringPayment()
        {
            Console.WriteLine("EditRecurringPayment()");

            // Schedule recurring payment 1st
            if (!ScheduleRecurringPayment())
                return false;

            // Change amount to pay, schedule and make payment to last forever
            SchedulingRequest request = new SchedulingRequest();
            request.RecurringID = this.RecurringID;
            request.RecurringPaymentsRemaining = null;
            request.RecurringPaymentAmount = new BluefinAmount(180.00);
            request.RecurringSchedule = RecurringSchedule.MONTHLY_10;
          
            Console.WriteLine("Scheduling Request ..."
                + LogHelper.ToLogString(request, "\n\t"));

            SchedulingResponse response = BluefinGateway.Schedule.Edit(request);

            Console.WriteLine("Scheduling Response ..."
                + LogHelper.ToLogString(response, "\n\t"));

            return
                response.Success() && this.RecurringID == response.RecurringID
                && response.RecurringSchedule == RecurringSchedule.MONTHLY_10
                && response.RecurringPaymentAmount != null && response.RecurringPaymentAmount.Value == 180.00
                && response.RecurringPaymentsRemaining == null
                ;
        }
    }
}
