﻿using System;
using System.Collections.Generic;

using Bluefin.Data;
using Bluefin.Web.Client;

namespace Bluefin_Dotnet_Guide
{
    /// <summary>
    /// Handy helpers to log data
    /// </summary>
    public class LogHelper
    {
        public static String MaskCardNo(String cardNo)
        {
            if (String.IsNullOrEmpty(cardNo) || cardNo.Length <= 4)
                return cardNo;
            else
            {
                int iLen = cardNo.Length;
                return
                    new String('X', iLen - 4) + cardNo.Substring(iLen - 4);
            }
        }
        public static String ToLogString(Response response, String separator)
        {
            String logString = "null";
            if (response == null)
                return logString;

            logString = ""
                + separator + "Success()           : " + response.Success()
                + separator + "Error               : " + response.Error
                + separator + "ErrorCode           : " + response.ErrorCode
                + separator + "ErrorMessage        : " + response.ErrorMessage
                ;

            return logString;
        }

        public static String ToLogString(TransactionResponse response, String separator)
        {
            String logString = "null";
            if (response == null)
                return logString;

            logString = ToLogString((Response)response, separator)
                + separator + "TransactionID       : " + response.TransactionID
                + separator + "TenderType          : " + response.TenderType
                + separator + "TransactionTimeStamp: " + response.TransactionTimestamp
                + separator + "AuthorizationCode   : " + response.AuthorizationCode
                + separator + "AuthorizationMessage: " + response.AuthorizationMessage
                + separator + "Amount              : " + (response.Amount == null ? "Not Set" : response.Amount.ToString())
                + separator + "AVSResponse         : " + response.AVSResponse
                + separator + "LastFour            : " + response.LastFour
                + separator + "Description         : " + response.Description
                + separator + "Approved            : " + response.Approved
                + separator + "Keyed               : " + response.Keyed
                + separator + "Swiped              : " + response.Swiped
                + separator + "Person              : " + ToLogString(response.Person, separator)
                ;

            return logString;
        }

        public static String ToLogString(TransactionStatusResponse response, String separator)
        {
            String logString = "null";
            if (response == null)
                return logString;

            logString = ToLogString((Response)response, separator)
                + separator + "Found               : " + response.Found
                + separator + "TransactionID       : " + response.TransactionID
                + separator + "TransactionTimeStamp: " + response.TransactionTimestamp
                + separator + "AuthorizationMessage: " + response.AuthorizationMessage
                + separator + "Amount              : " + (response.Amount == null ? "Not Set" : response.Amount.ToString())
                + separator + "Approved            : " + response.Approved
                ;

            return logString;
        }

        /// <summary>
        /// Returns log string of response. If response.Success() is false, outputs only Response fields.
        /// </summary>
        /// <param name="response">response to log</param>
        /// <param name="separator">separator to use between fields values</param>
        /// <returns></returns>
        public static String ToLogString(CardTransactionResponse response, String separator)
        {
            if (response == null)
                return "null";

            if (!response.Success())
                return ToLogString((Response)response, separator);

            return 
                ToLogString((TransactionResponse)response, separator)
                + separator + "CardExpiration      : " + response.CardExpiration
                + separator + "CardBrand           : " + response.CardBrand
                + separator + "CVVResponse         : " + response.CVVResponse
                ;
        }

        /// <summary>
        /// Returns log string of response. If response.Success() is false, outputs only Response fields.
        /// </summary>
        /// <param name="response">response to log</param>
        /// <param name="separator">separator to use between fields values</param>
        /// <returns>log string</returns>
        public static String ToLogString(CheckTransactionResponse response, String separator)
        {
            if (response == null)
                return "null";

            if (!response.Success())
                return ToLogString((Response)response, separator);

            return
                ToLogString((TransactionResponse)response, separator)
                + separator + "CheckNumber         : " + response.CheckNumber
                ;
        }

        public static String ToLogString(SchedulingResponse response, String separator)
        {
            String logString = "null";

            if (response != null)
                logString = ToLogString((Response)response, separator)
                    + separator + "RecurringID                 : " + response.RecurringID
                    + separator + "Status                      : " + response.Status
                    + separator + "TokenID                     : " + response.TokenID
                    + separator + "RecurringPaymentAmount      : " + (BluefinAmount.IsNull(response.RecurringPaymentAmount) ? "null" : response.RecurringPaymentAmount.ToString())
                    + separator + "RecurringPaymentsRemaining  : " + (BluefinInteger.IsNull(response.RecurringPaymentsRemaining) ? "null" : response.RecurringPaymentsRemaining.ToString())
                    + separator + "RecurringSchedule           : " + response.RecurringSchedule
                    + separator + "RecurringScheduleDescription: " + response.RecurringScheduleDescription
                    + separator + "StartDate                   : " + (BluefinDate.IsNull(response.StartDate) ? "null" : response.StartDate.ToString())
                    + separator + "Label                       : " + response.Label
                    + separator + "NextRecurringPaymentDate    : " + response.NextRecurringPaymentDate
                    ;

            return logString;
        }

        public static String ToLogString(TransactionRequest request, String separator)
        {
            String logString = "null";

            if (request == null)
                return logString;

            logString = "" 
                + separator + "Person              : " + ToLogString(request.Person, separator)
                + separator + "TenderType          : " + request.TenderType
                + separator + "TokenID             : " + request.TokenID
                + separator + "TransactionID       : " + request.TransactionID
                + separator + "Amount              : " + (request == null ? "Not Set" : request.Amount.ToString())
                + separator + "Description         : " + request.Description
                + separator + "Group               : " + request.Group
                + separator + "Cashier             : " + request.Cashier
                + separator + "CustomID            : " + request.CustomID
                + separator + "CustomData          : " + request.CustomData
                ;

            return logString;
        }

        public static String ToLogString(TokenizedTransactionRequest request, String separator)
        {
            String logString = "null";

            if (request != null)
                logString = ""
                    + separator + "TokenID             : " + request.TokenID
                    + separator + "Amount              : " + request.Amount
                    ;

            return logString;
        }

        public static String ToLogString(CardTransactionRequest request, String separator)
        {
            if (request == null)
                return "null"; // logString;

            return 
                ToLogString((TransactionRequest)request, separator)
                + separator + "CardNumber          : " + MaskCardNo(request.CardNumber)
                + separator + "CardExpiration      : " + request.CardExpiration
                + separator + "CardVerification    : " + request.CardVerification
                ;
        }

        public static String ToLogString(ReportRequest request, String separator)
        {
            String logString = "null";

            if (request != null)
                logString = ""
                + separator + "FileName            : " + request.FileName
                + separator + "PersistMode         : " + ((int)request.PersistMode).ToString()
                + separator + "ReportFormat        : " + request.ReportFormat
                ;
            return logString;
        }

        public static String ToLogString(TransactionsReportRequest request, String separator)
        {
            String logString = "null";

            if (request != null)
                logString = ToLogString((ReportRequest)request, separator)
                    + separator + "ActionDate          : " + request.ActionDate // == null ? "null" : request.ActionDate.Value.ToString()
                    + separator + "TenderType          : " + request.TenderType
                    + separator + "TransactionDate     : " + request.TransactionDate // == null ? "null" : request.TransactionDate.Value.ToString()
                   ;

            return logString;
        }

        public static String ToLogString(SchedulingRequest request, String separator)
        {
            String logString = "null";

            if (request != null)
                logString = ""
                    + separator + "Status                    : " + request.Status
                    + separator + "TokenID                   : " + request.TokenID
                    + separator + "RecurringPaymentAmount    : " + (BluefinAmount.IsNull(request.RecurringPaymentAmount) ? "null" : request.RecurringPaymentAmount.ToString())
                    + separator + "RecurringPaymentsRemaining: " + (BluefinInteger.IsNull(request.RecurringPaymentsRemaining) ? "null" : request.RecurringPaymentsRemaining.ToString())
                    + separator + "RecurringSchedule         : " + request.RecurringSchedule
                    + separator + "StartDate                 : " + (BluefinDate.IsNull(request.StartDate) ? "null" : request.StartDate.ToString())
                    + separator + "Label                     : " + request.Label
                    + separator + "RecurringID               : " + request.RecurringID
                    ;

            return logString;
        }

        public static String ToLogString(TransactionsReportResponse response, String separator)
        {
            if (response == null)
                return "null";

            if (!response.Success())
                return ToLogString((Response)response, separator);

            return 
                ToLogString((Response)response, separator)
                    + separator + "FileName            : " + response.FileName
                    + separator + "Details             : " + ToLogString(response.Details, separator)
                    ;
        }

        public static String ToLogString(List<Transaction> details, String separator)
        {
            String logString = "null";

            if (details != null)
            {
                logString = "";
                foreach (Transaction transaction in details)
                    logString = logString
                        + separator + "TransactionID       : " + transaction.TransactionID
                        // TODO: more properties 
                        ;
            }

            return logString;
        }


        public static String ToLogString(Person data, String separator)
        {
            String logString = "null";
            if (data == null)
                return logString;

            separator += "    ";
            logString = ""
                + separator + "FirstName: " + data.FirstName
                + separator + "LastName : " + data.LastName
                + separator + "Address  : " + ToLogString(data.Address, separator)
                + separator + "Phone    : " + data.Phone
                + separator + "Email    : " + data.Email
                ;

            return logString;
        }

        public static String ToLogString(Address data, String separator)
        {
            String logString = "null";
            if (data == null)
                return logString;

            separator += "    ";
            logString = ""
                + separator + "StreetAddress1: " + data.StreetAddress1
                + separator + "StreetAddress2: " + data.StreetAddress2
                + separator + "City          : " + data.City
                + separator + "State         : " + data.State
                + separator + "Zip           : " + data.Zip
                + separator + "Country       : " + data.Country
                ;

            return logString;
        }

    }
}
