﻿using System;

using Bluefin.Data;
using Bluefin.Web.Client;

namespace Bluefin_Dotnet_Guide
{
    /// <summary>
    /// Handy helpers for other projects
    /// </summary>
    public static class TransactionsHelper
    {
        /// <summary>
        /// Returns sample Card Transaction Request for Sale
        /// </summary>
        /// <returns></returns>
        public static SwipedCardTransactionRequest SampleSwipedCardTransaction(String cardTracks)
        {
            SwipedCardTransactionRequest sctr = new SwipedCardTransactionRequest();

            sctr.Amount = new BluefinAmount(176.58);
            sctr.CardTracks = cardTracks;
            sctr.Description = "API 1.2 Test Transaction";
            sctr.Cashier = "NUnit";
            sctr.CustomData = "NUnit Custom Data";

            return sctr;
        }

        /// <summary>
        /// Returns sample Card Transaction Request for Sale
        /// </summary>
        /// <returns></returns>
        public static CardTransactionRequest SampleCardTransaction()
        {
            CardTransactionRequest ctr = new CardTransactionRequest();
            ctr.Amount = new BluefinAmount(176.58);
            ctr.Description = "Bluefin_Dotnet_Guide";
            ctr.CardNumber = "4444333322221111";
            ctr.CardExpiration = "0315";
            ctr.CardVerification = "315";

            // Add Person data container and fill it with data
            ctr.Person = new Person();
            ctr.Person.FirstName = "John";
            ctr.Person.LastName = "Smith";
            ctr.Person.Phone = "212-555-1212";

            // Add Person's Address data container and fill it with data
            ctr.Person.Address = new Address();
            ctr.Person.Address.StreetAddress1 = "123 Main St.";
            ctr.Person.Address.City = "Anytown";
            ctr.Person.Address.State = "NY";
            ctr.Person.Address.Zip = "10101";

            return ctr;
        }

        public static CheckTransactionRequest SampleCheckTransaction()
        {
            CheckTransactionRequest ctr = new CheckTransactionRequest();

            // ctr.Amount = 176.58;
            ctr.Amount = new BluefinAmount(176.58);
            ctr.Description = "Bluefin_Dotnet_Guide";

            ctr.Cashier = "Walkthrough";
            ctr.BankRoutingNumber = "061000052";
            ctr.BankAccountNumber = "0000987654";
            ctr.CheckNumber = "00123";
            ctr.ACHAccountType = ACHAccountType.CHECKING;
            ctr.SECCode = SECCode.WEB;

            ctr.Person = new Person();
            ctr.Person.FirstName = "John";
            ctr.Person.LastName = "Smith";
            ctr.Person.Phone = "212-555-1212";
            ctr.Person.Address = new Address();
            ctr.Person.Address.StreetAddress1 = "123 Main St.";
            ctr.Person.Address.City = "Anytown";
            ctr.Person.Address.State = "NY";
            ctr.Person.Address.Zip = "10101";

            return ctr;
        }
    }
}
